@@ -14,7 +14,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.arrow.c;
 
 import static org.apache.arrow.vector.testing.ValueVectorDataPopulator.setVector;
@@ -35,7 +34,6 @@ import java.util.UUID;
 import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 import java.util.stream.Stream;
-
 import org.apache.arrow.memory.ArrowBuf;
 import org.apache.arrow.memory.BufferAllocator;
 import org.apache.arrow.memory.RootAllocator;
@@ -80,11 +78,15 @@ import org.apache.arrow.vector.ValueVector;
 import org.apache.arrow.vector.VarBinaryVector;
 import org.apache.arrow.vector.VarCharVector;
 import org.apache.arrow.vector.VectorSchemaRoot;
+import org.apache.arrow.vector.ViewVarBinaryVector;
+import org.apache.arrow.vector.ViewVarCharVector;
 import org.apache.arrow.vector.ZeroVector;
 import org.apache.arrow.vector.compare.VectorEqualsVisitor;
 import org.apache.arrow.vector.complex.FixedSizeListVector;
 import org.apache.arrow.vector.complex.LargeListVector;
+import org.apache.arrow.vector.complex.LargeListViewVector;
 import org.apache.arrow.vector.complex.ListVector;
+import org.apache.arrow.vector.complex.ListViewVector;
 import org.apache.arrow.vector.complex.MapVector;
 import org.apache.arrow.vector.complex.StructVector;
 import org.apache.arrow.vector.complex.UnionVector;
@@ -136,7 +138,8 @@ public class RoundtripTest {
       }
 
       // Consumer imports vector
-      FieldVector imported = Data.importVector(childAllocator, consumerArrowArray, consumerArrowSchema, null);
+      FieldVector imported =
+          Data.importVector(childAllocator, consumerArrowArray, consumerArrowSchema, null);
       if (!(imported instanceof NullVector)) {
         assertEquals(childAllocator, imported.getAllocator());
       }
@@ -167,20 +170,25 @@ public class RoundtripTest {
 
   boolean roundtrip(FieldVector vector, Class<?> clazz) {
     List<ArrowBuf> fieldBuffers = vector.getFieldBuffers();
-    List<Integer> orgRefCnts = fieldBuffers.stream().map(buf -> buf.refCnt()).collect(Collectors.toList());
+    List<Integer> orgRefCnts =
+        fieldBuffers.stream().map(buf -> buf.refCnt()).collect(Collectors.toList());
     long orgMemorySize = allocator.getAllocatedMemory();
 
     boolean result = false;
     try (ValueVector imported = vectorRoundtrip(vector)) {
-      assertTrue(clazz.isInstance(imported), String.format("expected %s but was %s", clazz, imported.getClass()));
+      assertTrue(
+          clazz.isInstance(imported),
+          String.format("expected %s but was %s", clazz, imported.getClass()));
       result = VectorEqualsVisitor.vectorEquals(vector, imported);
     }
 
     // Check that the ref counts of the buffers are the same after the roundtrip
-    IntStream.range(0, orgRefCnts.size()).forEach(i -> {
-      ArrowBuf buf = fieldBuffers.get(i);
-      assertEquals(buf.refCnt(), orgRefCnts.get(i));
-    });
+    IntStream.range(0, orgRefCnts.size())
+        .forEach(
+            i -> {
+              ArrowBuf buf = fieldBuffers.get(i);
+              assertEquals(buf.refCnt(), orgRefCnts.get(i));
+            });
 
     assertEquals(orgMemorySize, allocator.getAllocatedMemory());
 
@@ -309,7 +317,7 @@ public class RoundtripTest {
   @Test
   public void testFixedSizeBinaryVector() {
     try (final FixedSizeBinaryVector vector = new FixedSizeBinaryVector("v", allocator, 2)) {
-      setVector(vector, new byte[] { 0b0000, 0b0001 }, new byte[] { 0b0010, 0b0011 });
+      setVector(vector, new byte[] {0b0000, 0b0001}, new byte[] {0b0010, 0b0011});
       assertTrue(roundtrip(vector, FixedSizeBinaryVector.class));
     }
   }
@@ -511,11 +519,80 @@ public class RoundtripTest {
   @Test
   public void testVarBinaryVector() {
     try (final VarBinaryVector vector = new VarBinaryVector("v", allocator)) {
-      setVector(vector, "abc".getBytes(), "def".getBytes(), null);
+      setVector(
+          vector,
+          "abc".getBytes(StandardCharsets.UTF_8),
+          "def".getBytes(StandardCharsets.UTF_8),
+          null);
       assertTrue(roundtrip(vector, VarBinaryVector.class));
     }
   }
 
+  @Test
+  public void testViewVector() {
+    // ViewVarCharVector with short strings
+    try (final ViewVarCharVector vector = new ViewVarCharVector("v1", allocator)) {
+      setVector(
+          vector,
+          "abc".getBytes(StandardCharsets.UTF_8),
+          "def".getBytes(StandardCharsets.UTF_8),
+          null);
+      assertTrue(roundtrip(vector, ViewVarCharVector.class));
+    }
+
+    // ViewVarCharVector with long strings
+    try (final ViewVarCharVector vector = new ViewVarCharVector("v2", allocator)) {
+      setVector(
+          vector,
+          "01234567890123".getBytes(StandardCharsets.UTF_8),
+          "01234567890123567".getBytes(StandardCharsets.UTF_8),
+          null);
+      assertTrue(roundtrip(vector, ViewVarCharVector.class));
+    }
+
+    // ViewVarBinaryVector with short values
+    try (final ViewVarBinaryVector vector = new ViewVarBinaryVector("v3", allocator)) {
+      setVector(
+          vector,
+          "abc".getBytes(StandardCharsets.UTF_8),
+          "def".getBytes(StandardCharsets.UTF_8),
+          null);
+      assertTrue(roundtrip(vector, ViewVarBinaryVector.class));
+    }
+
+    // ViewVarBinaryVector with long values
+    try (final ViewVarBinaryVector vector = new ViewVarBinaryVector("v4", allocator)) {
+      setVector(
+          vector,
+          "01234567890123".getBytes(StandardCharsets.UTF_8),
+          "01234567890123567".getBytes(StandardCharsets.UTF_8),
+          null);
+      assertTrue(roundtrip(vector, ViewVarBinaryVector.class));
+    }
+
+    List<byte[]> byteArrayList = new ArrayList<>();
+    for (int i = 1; i <= 500; i++) {
+      StringBuilder sb = new StringBuilder(i);
+      for (int j = 0; j < i; j++) {
+        sb.append(j); // or any other character
+      }
+      byte[] bytes = sb.toString().getBytes(StandardCharsets.UTF_8);
+      byteArrayList.add(bytes);
+    }
+
+    // ViewVarCharVector with short long strings with multiple data buffers
+    try (final ViewVarCharVector vector = new ViewVarCharVector("v5", allocator)) {
+      setVector(vector, byteArrayList.toArray(new byte[0][]));
+      assertTrue(roundtrip(vector, ViewVarCharVector.class));
+    }
+
+    // ViewVarBinaryVector with short long strings with multiple data buffers
+    try (final ViewVarBinaryVector vector = new ViewVarBinaryVector("v6", allocator)) {
+      setVector(vector, byteArrayList.toArray(new byte[0][]));
+      assertTrue(roundtrip(vector, ViewVarBinaryVector.class));
+    }
+  }
+
   @Test
   public void testVarCharVector() {
     try (final VarCharVector vector = new VarCharVector("v", allocator)) {
@@ -537,7 +614,7 @@ public class RoundtripTest {
 
       String str = "hello world";
       try (ArrowBuf buf = allocator.buffer(16)) {
-        buf.setBytes(0, str.getBytes());
+        buf.setBytes(0, str.getBytes(StandardCharsets.UTF_8));
         binHolder.start = 0;
         binHolder.end = str.length();
         binHolder.buffer = buf;
@@ -560,8 +637,11 @@ public class RoundtripTest {
   @Test
   public void testListVector() {
     try (final ListVector vector = ListVector.empty("v", allocator)) {
-      setVector(vector, Arrays.stream(new int[] { 1, 2 }).boxed().collect(Collectors.toList()),
-          Arrays.stream(new int[] { 3, 4 }).boxed().collect(Collectors.toList()), new ArrayList<Integer>());
+      setVector(
+          vector,
+          Arrays.stream(new int[] {1, 2}).boxed().collect(Collectors.toList()),
+          Arrays.stream(new int[] {3, 4}).boxed().collect(Collectors.toList()),
+          new ArrayList<Integer>());
       assertTrue(roundtrip(vector, ListVector.class));
     }
   }
@@ -577,8 +657,11 @@ public class RoundtripTest {
   @Test
   public void testLargeListVector() {
     try (final LargeListVector vector = LargeListVector.empty("v", allocator)) {
-      setVector(vector, Arrays.stream(new int[] { 1, 2 }).boxed().collect(Collectors.toList()),
-          Arrays.stream(new int[] { 3, 4 }).boxed().collect(Collectors.toList()), new ArrayList<Integer>());
+      setVector(
+          vector,
+          Arrays.stream(new int[] {1, 2}).boxed().collect(Collectors.toList()),
+          Arrays.stream(new int[] {3, 4}).boxed().collect(Collectors.toList()),
+          new ArrayList<Integer>());
       assertTrue(roundtrip(vector, LargeListVector.class));
     }
   }
@@ -586,12 +669,54 @@ public class RoundtripTest {
   @Test
   public void testFixedSizeListVector() {
     try (final FixedSizeListVector vector = FixedSizeListVector.empty("v", 2, allocator)) {
-      setVector(vector, Arrays.stream(new int[] { 1, 2 }).boxed().collect(Collectors.toList()),
-          Arrays.stream(new int[] { 3, 4 }).boxed().collect(Collectors.toList()));
+      setVector(
+          vector,
+          Arrays.stream(new int[] {1, 2}).boxed().collect(Collectors.toList()),
+          Arrays.stream(new int[] {3, 4}).boxed().collect(Collectors.toList()));
       assertTrue(roundtrip(vector, FixedSizeListVector.class));
     }
   }
 
+  @Test
+  public void testListViewVector() {
+    try (final ListViewVector vector = ListViewVector.empty("v", allocator)) {
+      setVector(
+          vector,
+          Arrays.stream(new int[] {1, 2}).boxed().collect(Collectors.toList()),
+          Arrays.stream(new int[] {3, 4}).boxed().collect(Collectors.toList()),
+          new ArrayList<Integer>());
+      assertTrue(roundtrip(vector, ListViewVector.class));
+    }
+  }
+
+  @Test
+  public void testEmptyListViewVector() {
+    try (final ListViewVector vector = ListViewVector.empty("v", allocator)) {
+      setVector(vector, new ArrayList<Integer>());
+      assertTrue(roundtrip(vector, ListViewVector.class));
+    }
+  }
+
+  @Test
+  public void testLargeListViewVector() {
+    try (final LargeListViewVector vector = LargeListViewVector.empty("v", allocator)) {
+      setVector(
+          vector,
+          Arrays.stream(new int[] {1, 2}).boxed().collect(Collectors.toList()),
+          Arrays.stream(new int[] {3, 4}).boxed().collect(Collectors.toList()),
+          new ArrayList<Integer>());
+      assertTrue(roundtrip(vector, LargeListViewVector.class));
+    }
+  }
+
+  @Test
+  public void testEmptyLargeListViewVector() {
+    try (final LargeListViewVector vector = LargeListViewVector.empty("v", allocator)) {
+      setVector(vector, new ArrayList<Integer>());
+      assertTrue(roundtrip(vector, LargeListViewVector.class));
+    }
+  }
+
   @Test
   public void testMapVector() {
     int count = 5;
@@ -638,8 +763,8 @@ public class RoundtripTest {
   public void testStructVector() {
     try (final StructVector vector = StructVector.empty("v", allocator)) {
       Map<String, List<Integer>> data = new HashMap<>();
-      data.put("col_1", Arrays.stream(new int[] { 1, 2 }).boxed().collect(Collectors.toList()));
-      data.put("col_2", Arrays.stream(new int[] { 3, 4 }).boxed().collect(Collectors.toList()));
+      data.put("col_1", Arrays.stream(new int[] {1, 2}).boxed().collect(Collectors.toList()));
+      data.put("col_2", Arrays.stream(new int[] {3, 4}).boxed().collect(Collectors.toList()));
       setVector(vector, data);
       assertTrue(roundtrip(vector, StructVector.class));
     }
@@ -648,7 +773,8 @@ public class RoundtripTest {
   @Test
   public void testExtensionTypeVector() {
     ExtensionTypeRegistry.register(new UuidType());
-    final Schema schema = new Schema(Collections.singletonList(Field.nullable("a", new UuidType())));
+    final Schema schema =
+        new Schema(Collections.singletonList(Field.nullable("a", new UuidType())));
     try (final VectorSchemaRoot root = VectorSchemaRoot.create(schema, allocator)) {
       // Fill with data
       UUID u1 = UUID.randomUUID();
@@ -667,8 +793,12 @@ public class RoundtripTest {
 
       final Field field = importedRoot.getSchema().getFields().get(0);
       final UuidType expectedType = new UuidType();
-      assertEquals(field.getMetadata().get(ExtensionType.EXTENSION_METADATA_KEY_NAME), expectedType.extensionName());
-      assertEquals(field.getMetadata().get(ExtensionType.EXTENSION_METADATA_KEY_METADATA), expectedType.serialize());
+      assertEquals(
+          field.getMetadata().get(ExtensionType.EXTENSION_METADATA_KEY_NAME),
+          expectedType.extensionName());
+      assertEquals(
+          field.getMetadata().get(ExtensionType.EXTENSION_METADATA_KEY_METADATA),
+          expectedType.serialize());
 
       final UuidVector deserialized = (UuidVector) importedRoot.getFieldVectors().get(0);
       assertEquals(vector.getValueCount(), deserialized.getValueCount());
@@ -699,7 +829,8 @@ public class RoundtripTest {
         }
       }
       // Consumer imports vector
-      imported = Data.importVectorSchemaRoot(allocator, consumerArrowArray, consumerArrowSchema, null);
+      imported =
+          Data.importVectorSchemaRoot(allocator, consumerArrowArray, consumerArrowSchema, null);
     }
 
     // Ensure that imported VectorSchemaRoot is valid even after C Data Interface
@@ -711,7 +842,8 @@ public class RoundtripTest {
   }
 
   /**
-   * Tests exporting Table and importing back to VSR. Importing back to Table is not supported at present.
+   * Tests exporting Table and importing back to VSR. Importing back to Table is not supported at
+   * present.
    */
   @Test
   public void testTable() {
@@ -720,8 +852,7 @@ public class RoundtripTest {
     // Consumer allocates empty structures
     try (ArrowSchema consumerArrowSchema = ArrowSchema.allocateNew(allocator);
         ArrowArray consumerArrowArray = ArrowArray.allocateNew(allocator)) {
-      try (
-          VectorSchemaRoot vsr = createTestVSR();
+      try (VectorSchemaRoot vsr = createTestVSR();
           Table table = new Table(vsr)) {
         // Producer creates structures from existing memory pointers
         try (ArrowSchema arrowSchema = ArrowSchema.wrap(consumerArrowSchema.memoryAddress());
@@ -731,7 +862,8 @@ public class RoundtripTest {
         }
       }
       // Consumer imports vector
-      imported = Data.importVectorSchemaRoot(allocator, consumerArrowArray, consumerArrowSchema, null);
+      imported =
+          Data.importVectorSchemaRoot(allocator, consumerArrowArray, consumerArrowSchema, null);
     }
 
     // Ensure that imported VectorSchemaRoot is valid even after C Data Interface
@@ -753,10 +885,11 @@ public class RoundtripTest {
       try (VectorSchemaRoot testVSR1 = createTestVSR();
           VectorSchemaRoot testVSR2 = createTestVSR()) {
         // Merge two VSRs to produce duplicated field names
-        final VectorSchemaRoot vsr = new VectorSchemaRoot(
-            Stream.concat(
-                testVSR1.getFieldVectors().stream(),
-                testVSR2.getFieldVectors().stream()).collect(Collectors.toList()));
+        final VectorSchemaRoot vsr =
+            new VectorSchemaRoot(
+                Stream.concat(
+                        testVSR1.getFieldVectors().stream(), testVSR2.getFieldVectors().stream())
+                    .collect(Collectors.toList()));
         // Producer creates structures from existing memory pointers
         try (ArrowSchema arrowSchema = ArrowSchema.wrap(consumerArrowSchema.memoryAddress());
             ArrowArray arrowArray = ArrowArray.wrap(consumerArrowArray.memoryAddress())) {
@@ -765,17 +898,19 @@ public class RoundtripTest {
         }
       }
       // Consumer imports vector
-      imported = Data.importVectorSchemaRoot(allocator, consumerArrowArray, consumerArrowSchema, null);
+      imported =
+          Data.importVectorSchemaRoot(allocator, consumerArrowArray, consumerArrowSchema, null);
     }
 
     // Ensure that imported VectorSchemaRoot is valid even after C Data Interface
     // structures are closed
     try (VectorSchemaRoot testVSR1 = createTestVSR();
         VectorSchemaRoot testVSR2 = createTestVSR()) {
-      final VectorSchemaRoot original = new VectorSchemaRoot(
-          Stream.concat(
-              testVSR1.getFieldVectors().stream(),
-              testVSR2.getFieldVectors().stream()).collect(Collectors.toList()));
+      final VectorSchemaRoot original =
+          new VectorSchemaRoot(
+              Stream.concat(
+                      testVSR1.getFieldVectors().stream(), testVSR2.getFieldVectors().stream())
+                  .collect(Collectors.toList()));
       assertTrue(imported.equals(original));
     }
     imported.close();
@@ -783,10 +918,14 @@ public class RoundtripTest {
 
   @Test
   public void testSchema() {
-    Field decimalField = new Field("inner1", FieldType.nullable(new ArrowType.Decimal(19, 4, 128)), null);
+    Field decimalField =
+        new Field("inner1", FieldType.nullable(new ArrowType.Decimal(19, 4, 128)), null);
     Field strField = new Field("inner2", FieldType.nullable(new ArrowType.Utf8()), null);
-    Field itemField = new Field("col1", FieldType.nullable(new ArrowType.Struct()),
-        Arrays.asList(decimalField, strField));
+    Field itemField =
+        new Field(
+            "col1",
+            FieldType.nullable(new ArrowType.Struct()),
+            Arrays.asList(decimalField, strField));
     Field intField = new Field("col2", FieldType.nullable(new ArrowType.Int(32, true)), null);
     Schema schema = new Schema(Arrays.asList(itemField, intField));
     // Consumer allocates empty ArrowSchema
@@ -835,9 +974,12 @@ public class RoundtripTest {
       consumerArrowArray.markReleased();
 
       // Consumer tried to imports vector but fails
-      Exception e = assertThrows(IllegalStateException.class, () -> {
-        Data.importVector(allocator, consumerArrowArray, consumerArrowSchema, null);
-      });
+      Exception e =
+          assertThrows(
+              IllegalStateException.class,
+              () -> {
+                Data.importVector(allocator, consumerArrowArray, consumerArrowSchema, null);
+              });
 
       assertEquals("Cannot import released ArrowArray", e.getMessage());
     }
@@ -886,7 +1028,8 @@ public class RoundtripTest {
     @Override
     public ArrowType deserialize(ArrowType storageType, String serializedData) {
       if (!storageType.equals(storageType())) {
-        throw new UnsupportedOperationException("Cannot construct UuidType from underlying type " + storageType);
+        throw new UnsupportedOperationException(
+            "Cannot construct UuidType from underlying type " + storageType);
       }
       return new UuidType();
     }
@@ -904,7 +1047,8 @@ public class RoundtripTest {
 
   static class UuidVector extends ExtensionTypeVector<FixedSizeBinaryVector> {
 
-    public UuidVector(String name, BufferAllocator allocator, FixedSizeBinaryVector underlyingVector) {
+    public UuidVector(
+        String name, BufferAllocator allocator, FixedSizeBinaryVector underlyingVector) {
       super(name, allocator, underlyingVector);
     }
 
