@@ -22,7 +22,10 @@ module org.apache.arrow.memory.core {
   exports org.apache.arrow.memory.util.hash;
   exports org.apache.arrow.util;
 
+  requires java.compiler;
   requires transitive jdk.unsupported;
-  requires jsr305;
+  requires static org.checkerframework.checker.qual;
+  requires static org.immutables.value.annotations;
+  requires static com.google.errorprone.annotations;
   requires org.slf4j;
 }
