@@ -14,7 +14,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.arrow.vector.ipc;
 
 import static com.fasterxml.jackson.core.JsonToken.END_ARRAY;
@@ -23,26 +22,37 @@ import static com.fasterxml.jackson.core.JsonToken.START_ARRAY;
 import static com.fasterxml.jackson.core.JsonToken.START_OBJECT;
 import static org.apache.arrow.vector.BufferLayout.BufferType.DATA;
 import static org.apache.arrow.vector.BufferLayout.BufferType.OFFSET;
+import static org.apache.arrow.vector.BufferLayout.BufferType.SIZE;
 import static org.apache.arrow.vector.BufferLayout.BufferType.TYPE;
 import static org.apache.arrow.vector.BufferLayout.BufferType.VALIDITY;
+import static org.apache.arrow.vector.BufferLayout.BufferType.VARIADIC_DATA_BUFFERS;
+import static org.apache.arrow.vector.BufferLayout.BufferType.VIEWS;
 
+import com.fasterxml.jackson.core.JsonParseException;
+import com.fasterxml.jackson.core.JsonParser;
+import com.fasterxml.jackson.core.JsonParser.Feature;
+import com.fasterxml.jackson.core.JsonToken;
+import com.fasterxml.jackson.databind.MapperFeature;
+import com.fasterxml.jackson.databind.MappingJsonFactory;
+import com.fasterxml.jackson.databind.ObjectMapper;
 import java.io.File;
 import java.io.IOException;
 import java.math.BigDecimal;
 import java.math.BigInteger;
+import java.nio.ByteBuffer;
+import java.nio.ByteOrder;
 import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
-
 import org.apache.arrow.memory.ArrowBuf;
 import org.apache.arrow.memory.BufferAllocator;
 import org.apache.arrow.util.Preconditions;
+import org.apache.arrow.vector.BaseVariableWidthViewVector;
 import org.apache.arrow.vector.BigIntVector;
 import org.apache.arrow.vector.BitVectorHelper;
 import org.apache.arrow.vector.BufferLayout.BufferType;
@@ -61,8 +71,11 @@ import org.apache.arrow.vector.VectorSchemaRoot;
 import org.apache.arrow.vector.dictionary.Dictionary;
 import org.apache.arrow.vector.dictionary.DictionaryProvider;
 import org.apache.arrow.vector.ipc.message.ArrowFieldNode;
-import org.apache.arrow.vector.types.Types;
+import org.apache.arrow.vector.types.Types.MinorType;
 import org.apache.arrow.vector.types.pojo.ArrowType;
+import org.apache.arrow.vector.types.pojo.ArrowType.LargeListView;
+import org.apache.arrow.vector.types.pojo.ArrowType.ListView;
+import org.apache.arrow.vector.types.pojo.ArrowType.Union;
 import org.apache.arrow.vector.types.pojo.Field;
 import org.apache.arrow.vector.types.pojo.Schema;
 import org.apache.arrow.vector.util.DecimalUtility;
@@ -70,15 +83,9 @@ import org.apache.arrow.vector.util.DictionaryUtility;
 import org.apache.commons.codec.DecoderException;
 import org.apache.commons.codec.binary.Hex;
 
-import com.fasterxml.jackson.core.JsonParseException;
-import com.fasterxml.jackson.core.JsonParser;
-import com.fasterxml.jackson.core.JsonToken;
-import com.fasterxml.jackson.databind.MapperFeature;
-import com.fasterxml.jackson.databind.MappingJsonFactory;
-import com.fasterxml.jackson.databind.ObjectMapper;
-
 /**
- * A reader for JSON files that translates them into vectors. This reader is used for integration tests.
+ * A reader for JSON files that translates them into vectors. This reader is used for integration
+ * tests.
  *
  * <p>This class uses a streaming parser API, method naming tends to reflect this implementation
  * detail.
@@ -92,19 +99,22 @@ public class JsonFileReader implements AutoCloseable, DictionaryProvider {
 
   /**
    * Constructs a new instance.
+   *
    * @param inputFile The file to read.
    * @param allocator The allocator to use for allocating buffers.
    */
-  public JsonFileReader(File inputFile, BufferAllocator allocator) throws JsonParseException, IOException {
+  public JsonFileReader(File inputFile, BufferAllocator allocator)
+      throws JsonParseException, IOException {
     super();
     this.allocator = allocator;
-    MappingJsonFactory jsonFactory = new MappingJsonFactory(new ObjectMapper()
-        //ignore case for enums
-        .configure(MapperFeature.ACCEPT_CASE_INSENSITIVE_ENUMS, true)
-    );
+    MappingJsonFactory jsonFactory =
+        new MappingJsonFactory(
+            new ObjectMapper()
+                // ignore case for enums
+                .configure(MapperFeature.ACCEPT_CASE_INSENSITIVE_ENUMS, true));
     this.parser = jsonFactory.createParser(inputFile);
     // Allow reading NaN for floating point values
-    this.parser.configure(JsonParser.Feature.ALLOW_NON_NUMERIC_NUMBERS, true);
+    this.parser.configure(Feature.ALLOW_NON_NUMERIC_NUMBERS, true);
   }
 
   @Override
@@ -157,7 +167,8 @@ public class JsonFileReader implements AutoCloseable, DictionaryProvider {
       long id = readNextField("id", Long.class);
       Dictionary dict = dictionaries.get(id);
       if (dict == null) {
-        throw new IllegalArgumentException("Dictionary with id: " + id + " missing encoding from schema Field");
+        throw new IllegalArgumentException(
+            "Dictionary with id: " + id + " missing encoding from schema Field");
       }
 
       // Read the dictionary record batch
@@ -174,14 +185,12 @@ public class JsonFileReader implements AutoCloseable, DictionaryProvider {
     }
 
     if (token != END_ARRAY) {
-      throw new IllegalArgumentException("Invalid token: " + token + " expected end of array at " +
-        parser.getTokenLocation());
+      throw new IllegalArgumentException(
+          "Invalid token: " + token + " expected end of array at " + parser.getTokenLocation());
     }
   }
 
-  /**
-   * Reads the next record batch from the file into <code>root</code>.
-   */
+  /** Reads the next record batch from the file into <code>root</code>. */
   public boolean read(VectorSchemaRoot root) throws IOException {
     JsonToken t = parser.nextToken();
     if (t == START_OBJECT) {
@@ -208,9 +217,7 @@ public class JsonFileReader implements AutoCloseable, DictionaryProvider {
     }
   }
 
-  /**
-   * Returns the next record batch from the file.
-   */
+  /** Returns the next record batch from the file. */
   public VectorSchemaRoot read() throws IOException {
     JsonToken t = parser.nextToken();
     if (t == START_OBJECT) {
@@ -270,250 +277,364 @@ public class JsonFileReader implements AutoCloseable, DictionaryProvider {
     }
   }
 
+  /**
+   * Read all the variadic data buffers from the parser.
+   *
+   * @param allocator BufferAllocator
+   * @param variadicBuffersCount Number of variadic buffers
+   * @return List of ArrowBuf
+   * @throws IOException throws IOException in a failure
+   */
+  List<ArrowBuf> readVariadicBuffers(BufferAllocator allocator, int variadicBuffersCount)
+      throws IOException {
+    readToken(START_ARRAY);
+    ArrayList<ArrowBuf> dataBuffers = new ArrayList<>(variadicBuffersCount);
+    for (int i = 0; i < variadicBuffersCount; i++) {
+      parser.nextToken();
+      final byte[] value;
+
+      String variadicStr = parser.readValueAs(String.class);
+      if (variadicStr == null) {
+        value = new byte[0];
+      } else {
+        value = decodeHexSafe(variadicStr);
+      }
+
+      ArrowBuf buf = allocator.buffer(value.length);
+      buf.writeBytes(value);
+      dataBuffers.add(buf);
+    }
+    readToken(END_ARRAY);
+    return dataBuffers;
+  }
+
+  private ArrowBuf readViewBuffers(
+      BufferAllocator allocator, int count, List<Integer> variadicBufferIndices, MinorType type)
+      throws IOException {
+    readToken(START_ARRAY);
+    ArrayList<byte[]> values = new ArrayList<>(count);
+    long bufferSize = 0L;
+    for (int i = 0; i < count; i++) {
+      readToken(START_OBJECT);
+      final int length = readNextField("SIZE", Integer.class);
+      byte[] value;
+      if (length > BaseVariableWidthViewVector.INLINE_SIZE) {
+        // PREFIX_HEX
+        final byte[] prefix = decodeHexSafe(readNextField("PREFIX_HEX", String.class));
+        // BUFFER_INDEX
+        final int bufferIndex = readNextField("BUFFER_INDEX", Integer.class);
+        if (variadicBufferIndices.isEmpty()) {
+          variadicBufferIndices.add(bufferIndex);
+        } else {
+          int lastBufferIndex = variadicBufferIndices.get(variadicBufferIndices.size() - 1);
+          if (lastBufferIndex != bufferIndex) {
+            variadicBufferIndices.add(bufferIndex);
+          }
+        }
+
+        // OFFSET
+        final int offset = readNextField("OFFSET", Integer.class);
+        ByteBuffer buffer =
+            ByteBuffer.allocate(BaseVariableWidthViewVector.ELEMENT_SIZE)
+                .order(ByteOrder.LITTLE_ENDIAN); // Allocate a ByteBuffer of size 16 bytes
+        buffer.putInt(length); // Write 'length' to bytes 0-3
+        buffer.put(prefix); // Write 'prefix' to bytes 4-7
+        buffer.putInt(bufferIndex); // Write 'bufferIndex' to bytes 8-11
+        buffer.putInt(offset); // Write 'offset' to bytes 12-15
+        value = buffer.array(); // Convert the ByteBuffer to a byte array
+      } else {
+        // in-line
+        ByteBuffer buffer =
+            ByteBuffer.allocate(BaseVariableWidthViewVector.ELEMENT_SIZE)
+                .order(ByteOrder.LITTLE_ENDIAN); // Allocate a ByteBuffer of size 16 bytes
+        buffer.putInt(length); // Write 'length' to bytes 0-3
+        // INLINE
+        if (type == MinorType.VIEWVARCHAR) {
+          buffer.put(readNextField("INLINED", String.class).getBytes(StandardCharsets.UTF_8));
+        } else {
+          String inlined = readNextField("INLINED", String.class);
+          if (inlined == null) {
+            buffer.put(new byte[length]);
+          } else {
+            buffer.put(decodeHexSafe(inlined));
+          }
+        }
+        value = buffer.array(); // Convert the ByteBuffer to a byte array
+      }
+      values.add(value);
+      bufferSize += value.length;
+      readToken(END_OBJECT);
+    }
+
+    ArrowBuf buf = allocator.buffer(bufferSize);
+
+    for (byte[] value : values) {
+      buf.writeBytes(value);
+    }
+    readToken(END_ARRAY);
+    return buf;
+  }
+
   private class BufferHelper {
-    BufferReader BIT = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final int bufferSize = BitVectorHelper.getValidityBufferSize(count);
-        ArrowBuf buf = allocator.buffer(bufferSize);
 
-        // C++ integration test fails without this.
-        buf.setZero(0, bufferSize);
+    BufferReader BIT =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final int bufferSize = BitVectorHelper.getValidityBufferSize(count);
+            ArrowBuf buf = allocator.buffer(bufferSize);
 
-        for (int i = 0; i < count; i++) {
-          parser.nextToken();
-          BitVectorHelper.setValidityBit(buf, i, parser.readValueAs(Boolean.class) ? 1 : 0);
-        }
+            // C++ integration test fails without this.
+            buf.setZero(0, bufferSize);
 
-        buf.writerIndex(bufferSize);
-        return buf;
-      }
-    };
+            for (int i = 0; i < count; i++) {
+              parser.nextToken();
+              BitVectorHelper.setValidityBit(buf, i, parser.readValueAs(Boolean.class) ? 1 : 0);
+            }
 
-    BufferReader DAY_MILLIS = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final long size = (long) count * IntervalDayVector.TYPE_WIDTH;
-        ArrowBuf buf = allocator.buffer(size);
+            buf.writerIndex(bufferSize);
+            return buf;
+          }
+        };
 
-        for (int i = 0; i < count; i++) {
-          readToken(START_OBJECT);
-          buf.writeInt(readNextField("days", Integer.class));
-          buf.writeInt(readNextField("milliseconds", Integer.class));
-          readToken(END_OBJECT);
-        }
+    BufferReader DAY_MILLIS =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final long size = (long) count * IntervalDayVector.TYPE_WIDTH;
+            ArrowBuf buf = allocator.buffer(size);
 
-        return buf;
-      }
-    };
+            for (int i = 0; i < count; i++) {
+              readToken(START_OBJECT);
+              buf.writeInt(readNextField("days", Integer.class));
+              buf.writeInt(readNextField("milliseconds", Integer.class));
+              readToken(END_OBJECT);
+            }
 
-    BufferReader MONTH_DAY_NANOS = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final long size = (long) count * IntervalMonthDayNanoVector.TYPE_WIDTH;
-        ArrowBuf buf = allocator.buffer(size);
+            return buf;
+          }
+        };
 
-        for (int i = 0; i < count; i++) {
-          readToken(START_OBJECT);
-          buf.writeInt(readNextField("months", Integer.class));
-          buf.writeInt(readNextField("days", Integer.class));
-          buf.writeLong(readNextField("nanoseconds", Long.class));
-          readToken(END_OBJECT);
-        }
+    BufferReader MONTH_DAY_NANOS =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final long size = (long) count * IntervalMonthDayNanoVector.TYPE_WIDTH;
+            ArrowBuf buf = allocator.buffer(size);
 
-        return buf;
-      }
-    };
+            for (int i = 0; i < count; i++) {
+              readToken(START_OBJECT);
+              buf.writeInt(readNextField("months", Integer.class));
+              buf.writeInt(readNextField("days", Integer.class));
+              buf.writeLong(readNextField("nanoseconds", Long.class));
+              readToken(END_OBJECT);
+            }
 
+            return buf;
+          }
+        };
 
-    BufferReader INT1 = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final long size = (long) count * TinyIntVector.TYPE_WIDTH;
-        ArrowBuf buf = allocator.buffer(size);
+    BufferReader INT1 =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final long size = (long) count * TinyIntVector.TYPE_WIDTH;
+            ArrowBuf buf = allocator.buffer(size);
 
-        for (int i = 0; i < count; i++) {
-          parser.nextToken();
-          buf.writeByte(parser.getByteValue());
-        }
+            for (int i = 0; i < count; i++) {
+              parser.nextToken();
+              buf.writeByte(parser.getByteValue());
+            }
 
-        return buf;
-      }
-    };
+            return buf;
+          }
+        };
 
-    BufferReader INT2 = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final long size = (long) count * SmallIntVector.TYPE_WIDTH;
-        ArrowBuf buf = allocator.buffer(size);
+    BufferReader INT2 =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final long size = (long) count * SmallIntVector.TYPE_WIDTH;
+            ArrowBuf buf = allocator.buffer(size);
 
-        for (int i = 0; i < count; i++) {
-          parser.nextToken();
-          buf.writeShort(parser.getShortValue());
-        }
+            for (int i = 0; i < count; i++) {
+              parser.nextToken();
+              buf.writeShort(parser.getShortValue());
+            }
 
-        return buf;
-      }
-    };
+            return buf;
+          }
+        };
 
-    BufferReader INT4 = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final long size = (long) count * IntVector.TYPE_WIDTH;
-        ArrowBuf buf = allocator.buffer(size);
+    BufferReader INT4 =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final long size = (long) count * IntVector.TYPE_WIDTH;
+            ArrowBuf buf = allocator.buffer(size);
 
-        for (int i = 0; i < count; i++) {
-          parser.nextToken();
-          buf.writeInt(parser.getIntValue());
-        }
+            for (int i = 0; i < count; i++) {
+              parser.nextToken();
+              buf.writeInt(parser.getIntValue());
+            }
 
-        return buf;
-      }
-    };
+            return buf;
+          }
+        };
 
-    BufferReader INT8 = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final long size = (long) count * BigIntVector.TYPE_WIDTH;
-        ArrowBuf buf = allocator.buffer(size);
+    BufferReader INT8 =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final long size = (long) count * BigIntVector.TYPE_WIDTH;
+            ArrowBuf buf = allocator.buffer(size);
 
-        for (int i = 0; i < count; i++) {
-          parser.nextToken();
-          String value = parser.getValueAsString();
-          buf.writeLong(Long.valueOf(value));
-        }
+            for (int i = 0; i < count; i++) {
+              parser.nextToken();
+              String value = parser.getValueAsString();
+              buf.writeLong(Long.valueOf(value));
+            }
 
-        return buf;
-      }
-    };
+            return buf;
+          }
+        };
 
-    BufferReader UINT1 = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final long size = (long) count * TinyIntVector.TYPE_WIDTH;
-        ArrowBuf buf = allocator.buffer(size);
+    BufferReader UINT1 =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final long size = (long) count * TinyIntVector.TYPE_WIDTH;
+            ArrowBuf buf = allocator.buffer(size);
 
-        for (int i = 0; i < count; i++) {
-          parser.nextToken();
-          buf.writeByte(parser.getShortValue() & 0xFF);
-        }
+            for (int i = 0; i < count; i++) {
+              parser.nextToken();
+              buf.writeByte(parser.getShortValue() & 0xFF);
+            }
 
-        return buf;
-      }
-    };
+            return buf;
+          }
+        };
 
-    BufferReader UINT2 = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final long size = (long) count * SmallIntVector.TYPE_WIDTH;
-        ArrowBuf buf = allocator.buffer(size);
+    BufferReader UINT2 =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final long size = (long) count * SmallIntVector.TYPE_WIDTH;
+            ArrowBuf buf = allocator.buffer(size);
 
-        for (int i = 0; i < count; i++) {
-          parser.nextToken();
-          buf.writeShort(parser.getIntValue() & 0xFFFF);
-        }
+            for (int i = 0; i < count; i++) {
+              parser.nextToken();
+              buf.writeShort(parser.getIntValue() & 0xFFFF);
+            }
 
-        return buf;
-      }
-    };
+            return buf;
+          }
+        };
 
-    BufferReader UINT4 = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final long size = (long) count * IntVector.TYPE_WIDTH;
-        ArrowBuf buf = allocator.buffer(size);
+    BufferReader UINT4 =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final long size = (long) count * IntVector.TYPE_WIDTH;
+            ArrowBuf buf = allocator.buffer(size);
 
-        for (int i = 0; i < count; i++) {
-          parser.nextToken();
-          buf.writeInt((int) parser.getLongValue());
-        }
+            for (int i = 0; i < count; i++) {
+              parser.nextToken();
+              buf.writeInt((int) parser.getLongValue());
+            }
 
-        return buf;
-      }
-    };
+            return buf;
+          }
+        };
 
-    BufferReader UINT8 = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final long size = (long) count * BigIntVector.TYPE_WIDTH;
-        ArrowBuf buf = allocator.buffer(size);
+    BufferReader UINT8 =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final long size = (long) count * BigIntVector.TYPE_WIDTH;
+            ArrowBuf buf = allocator.buffer(size);
 
-        for (int i = 0; i < count; i++) {
-          parser.nextToken();
-          BigInteger value = new BigInteger(parser.getValueAsString());
-          buf.writeLong(value.longValue());
-        }
+            for (int i = 0; i < count; i++) {
+              parser.nextToken();
+              BigInteger value = new BigInteger(parser.getValueAsString());
+              buf.writeLong(value.longValue());
+            }
 
-        return buf;
-      }
-    };
+            return buf;
+          }
+        };
 
-    BufferReader FLOAT4 = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final long size = (long) count * Float4Vector.TYPE_WIDTH;
-        ArrowBuf buf = allocator.buffer(size);
+    BufferReader FLOAT4 =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final long size = (long) count * Float4Vector.TYPE_WIDTH;
+            ArrowBuf buf = allocator.buffer(size);
 
-        for (int i = 0; i < count; i++) {
-          parser.nextToken();
-          buf.writeFloat(parser.getFloatValue());
-        }
+            for (int i = 0; i < count; i++) {
+              parser.nextToken();
+              buf.writeFloat(parser.getFloatValue());
+            }
 
-        return buf;
-      }
-    };
+            return buf;
+          }
+        };
 
-    BufferReader FLOAT8 = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final long size = (long) count * Float8Vector.TYPE_WIDTH;
-        ArrowBuf buf = allocator.buffer(size);
+    BufferReader FLOAT8 =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final long size = (long) count * Float8Vector.TYPE_WIDTH;
+            ArrowBuf buf = allocator.buffer(size);
 
-        for (int i = 0; i < count; i++) {
-          parser.nextToken();
-          buf.writeDouble(parser.getDoubleValue());
-        }
+            for (int i = 0; i < count; i++) {
+              parser.nextToken();
+              buf.writeDouble(parser.getDoubleValue());
+            }
 
-        return buf;
-      }
-    };
+            return buf;
+          }
+        };
 
-    BufferReader DECIMAL = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final long size = (long) count * DecimalVector.TYPE_WIDTH;
-        ArrowBuf buf = allocator.buffer(size);
+    BufferReader DECIMAL =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final long size = (long) count * DecimalVector.TYPE_WIDTH;
+            ArrowBuf buf = allocator.buffer(size);
 
-        for (int i = 0; i < count; i++) {
-          parser.nextToken();
-          BigDecimal decimalValue = new BigDecimal(parser.readValueAs(String.class));
-          DecimalUtility.writeBigDecimalToArrowBuf(decimalValue, buf, i, DecimalVector.TYPE_WIDTH);
-        }
+            for (int i = 0; i < count; i++) {
+              parser.nextToken();
+              BigDecimal decimalValue = new BigDecimal(parser.readValueAs(String.class));
+              DecimalUtility.writeBigDecimalToArrowBuf(
+                  decimalValue, buf, i, DecimalVector.TYPE_WIDTH);
+            }
 
-        buf.writerIndex(size);
-        return buf;
-      }
-    };
+            buf.writerIndex(size);
+            return buf;
+          }
+        };
 
-    BufferReader DECIMAL256 = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        final long size = (long) count * Decimal256Vector.TYPE_WIDTH;
-        ArrowBuf buf = allocator.buffer(size);
+    BufferReader DECIMAL256 =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            final long size = (long) count * Decimal256Vector.TYPE_WIDTH;
+            ArrowBuf buf = allocator.buffer(size);
 
-        for (int i = 0; i < count; i++) {
-          parser.nextToken();
-          BigDecimal decimalValue = new BigDecimal(parser.readValueAs(String.class));
-          DecimalUtility.writeBigDecimalToArrowBuf(decimalValue, buf, i, Decimal256Vector.TYPE_WIDTH);
-        }
+            for (int i = 0; i < count; i++) {
+              parser.nextToken();
+              BigDecimal decimalValue = new BigDecimal(parser.readValueAs(String.class));
+              DecimalUtility.writeBigDecimalToArrowBuf(
+                  decimalValue, buf, i, Decimal256Vector.TYPE_WIDTH);
+            }
 
-        buf.writerIndex(size);
-        return buf;
-      }
-    };
+            buf.writerIndex(size);
+            return buf;
+          }
+        };
 
-    ArrowBuf readBinaryValues(
-        BufferAllocator allocator, int count) throws IOException {
+    ArrowBuf readBinaryValues(BufferAllocator allocator, int count) throws IOException {
       ArrayList<byte[]> values = new ArrayList<>(count);
       long bufferSize = 0L;
       for (int i = 0; i < count; i++) {
@@ -532,8 +653,7 @@ public class JsonFileReader implements AutoCloseable, DictionaryProvider {
       return buf;
     }
 
-    ArrowBuf readStringValues(
-        BufferAllocator allocator, int count) throws IOException {
+    ArrowBuf readStringValues(BufferAllocator allocator, int count) throws IOException {
       ArrayList<byte[]> values = new ArrayList<>(count);
       long bufferSize = 0L;
       for (int i = 0; i < count; i++) {
@@ -552,56 +672,66 @@ public class JsonFileReader implements AutoCloseable, DictionaryProvider {
       return buf;
     }
 
-    BufferReader FIXEDSIZEBINARY = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        return readBinaryValues(allocator, count);
-      }
-    };
+    BufferReader FIXEDSIZEBINARY =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            return readBinaryValues(allocator, count);
+          }
+        };
 
-    BufferReader VARCHAR = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        return readStringValues(allocator, count);
-      }
-    };
+    BufferReader VARCHAR =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            return readStringValues(allocator, count);
+          }
+        };
 
-    BufferReader LARGEVARCHAR = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        return readStringValues(allocator, count);
-      }
-    };
+    BufferReader LARGEVARCHAR =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            return readStringValues(allocator, count);
+          }
+        };
 
-    BufferReader VARBINARY = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        return readBinaryValues(allocator, count);
-      }
-    };
+    BufferReader VARBINARY =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            return readBinaryValues(allocator, count);
+          }
+        };
 
-    BufferReader LARGEVARBINARY = new BufferReader() {
-      @Override
-      protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
-        return readBinaryValues(allocator, count);
-      }
-    };
+    BufferReader LARGEVARBINARY =
+        new BufferReader() {
+          @Override
+          protected ArrowBuf read(BufferAllocator allocator, int count) throws IOException {
+            return readBinaryValues(allocator, count);
+          }
+        };
   }
 
-  private ArrowBuf readIntoBuffer(BufferAllocator allocator, BufferType bufferType,
-                                  Types.MinorType type, int count) throws IOException {
+  private List<ArrowBuf> readIntoBuffer(
+      BufferAllocator allocator,
+      BufferType bufferType,
+      MinorType type,
+      int count,
+      List<Integer> variadicBufferIndices)
+      throws IOException {
     ArrowBuf buf;
 
     BufferHelper helper = new BufferHelper();
-
-    BufferReader reader = null;
+    BufferReader reader;
 
     if (bufferType.equals(VALIDITY)) {
       reader = helper.BIT;
-    } else if (bufferType.equals(OFFSET)) {
-      if (type == Types.MinorType.LARGELIST ||
-          type == Types.MinorType.LARGEVARCHAR ||
-          type == Types.MinorType.LARGEVARBINARY) {
+    } else if (bufferType.equals(OFFSET) || bufferType.equals(SIZE)) {
+      if (type == MinorType.LARGELIST
+          || type == MinorType.LARGEVARCHAR
+          || type == MinorType.LARGEVARBINARY
+          || type == MinorType.LARGELISTVIEW) {
         reader = helper.INT8;
       } else {
         reader = helper.INT4;
@@ -703,23 +833,32 @@ public class JsonFileReader implements AutoCloseable, DictionaryProvider {
         default:
           throw new UnsupportedOperationException("Cannot read array of type " + type);
       }
+    } else if (bufferType.equals(VIEWS)) {
+      return Collections.singletonList(
+          readViewBuffers(allocator, count, variadicBufferIndices, type));
+    } else if (bufferType.equals(VARIADIC_DATA_BUFFERS)) {
+      return readVariadicBuffers(allocator, variadicBufferIndices.size());
     } else {
       throw new InvalidArrowFileException("Unrecognized buffer type " + bufferType);
     }
 
     buf = reader.readBuffer(allocator, count);
-
     Preconditions.checkNotNull(buf);
-    return buf;
+    return Collections.singletonList(buf);
   }
 
-  private void readFromJsonIntoVector(Field field, FieldVector vector) throws JsonParseException, IOException {
+  private void readFromJsonIntoVector(Field field, FieldVector vector) throws IOException {
     ArrowType type = field.getType();
     TypeLayout typeLayout = TypeLayout.getTypeLayout(type);
     List<BufferType> vectorTypes = typeLayout.getBufferTypes();
-    ArrowBuf[] vectorBuffers = new ArrowBuf[vectorTypes.size()];
+    List<ArrowBuf> vectorBuffers = new ArrayList<>(vectorTypes.size());
+    List<Integer> variadicBufferIndices = new ArrayList<>();
+
+    if (!typeLayout.isFixedBufferCount()) {
+      vectorTypes.add(VARIADIC_DATA_BUFFERS);
+    }
     /*
-     * The order of inner buffers is :
+     * The order of inner buffers is:
      * Fixed width vector:
      *    -- validity buffer
      *    -- data buffer
@@ -738,35 +877,46 @@ public class JsonFileReader implements AutoCloseable, DictionaryProvider {
       // If currently reading dictionaries, field name is not important so don't check
       String name = readNextField("name", String.class);
       if (started && !Objects.equals(field.getName(), name)) {
-        throw new IllegalArgumentException("Expected field " + field.getName() + " but got " + name);
+        throw new IllegalArgumentException(
+            "Expected field " + field.getName() + " but got " + name);
       }
 
       /* Initialize the vector with required capacity but don't allocateNew since we would
        * be doing loadFieldBuffers.
        */
       int valueCount = readNextField("count", Integer.class);
+
       vector.setInitialCapacity(valueCount);
 
       for (int v = 0; v < vectorTypes.size(); v++) {
         BufferType bufferType = vectorTypes.get(v);
         nextFieldIs(bufferType.getName());
         int innerBufferValueCount = valueCount;
-        if (bufferType.equals(OFFSET) && !(type instanceof ArrowType.Union)) {
-          /* offset buffer has 1 additional value capacity except for dense unions */
+        if (bufferType.equals(OFFSET)
+            && !(type instanceof Union)
+            && !(type instanceof ListView)
+            && !(type instanceof LargeListView)) {
+          /* offset buffer has 1 additional value capacity except for dense unions and ListView */
           innerBufferValueCount = valueCount + 1;
         }
 
-        vectorBuffers[v] = readIntoBuffer(allocator, bufferType, vector.getMinorType(), innerBufferValueCount);
+        vectorBuffers.addAll(
+            readIntoBuffer(
+                allocator,
+                bufferType,
+                vector.getMinorType(),
+                innerBufferValueCount,
+                variadicBufferIndices));
       }
 
       int nullCount = 0;
       if (type instanceof ArrowType.Null) {
         nullCount = valueCount;
-      } else if (!(type instanceof ArrowType.Union)) {
-        nullCount = BitVectorHelper.getNullCount(vectorBuffers[0], valueCount);
+      } else if (!(type instanceof Union)) {
+        nullCount = BitVectorHelper.getNullCount(vectorBuffers.get(0), valueCount);
       }
       final ArrowFieldNode fieldNode = new ArrowFieldNode(valueCount, nullCount);
-      vector.loadFieldBuffers(fieldNode, Arrays.asList(vectorBuffers));
+      vector.loadFieldBuffers(fieldNode, vectorBuffers);
 
       /* read child vectors (if any) */
       List<Field> fields = field.getChildren();
@@ -774,7 +924,10 @@ public class JsonFileReader implements AutoCloseable, DictionaryProvider {
         List<FieldVector> vectorChildren = vector.getChildrenFromFields();
         if (fields.size() != vectorChildren.size()) {
           throw new IllegalArgumentException(
-                  "fields and children are not the same size: " + fields.size() + " != " + vectorChildren.size());
+              "fields and children are not the same size: "
+                  + fields.size()
+                  + " != "
+                  + vectorChildren.size());
         }
         nextFieldIs("children");
         readToken(START_ARRAY);
@@ -786,9 +939,10 @@ public class JsonFileReader implements AutoCloseable, DictionaryProvider {
         readToken(END_ARRAY);
       }
     }
+
     readToken(END_OBJECT);
 
-    for (ArrowBuf buffer: vectorBuffers) {
+    for (ArrowBuf buffer : vectorBuffers) {
       buffer.getReferenceManager().release();
     }
   }
@@ -811,7 +965,8 @@ public class JsonFileReader implements AutoCloseable, DictionaryProvider {
     }
   }
 
-  private <T> T readNextField(String expectedFieldName, Class<T> c) throws IOException, JsonParseException {
+  private <T> T readNextField(String expectedFieldName, Class<T> c)
+      throws IOException, JsonParseException {
     nextFieldIs(expectedFieldName);
     parser.nextToken();
     return parser.readValueAs(c);
@@ -830,5 +985,4 @@ public class JsonFileReader implements AutoCloseable, DictionaryProvider {
       throw new IllegalStateException("Expected " + expected + " but got " + t);
     }
   }
-
 }
